// The package containing our stubs.
import HelloWorld.*;

// HelloServer will use the naming service.
import org.omg.CosNaming.*;

// The package containing special exceptions thrown by the name service.
import org.omg.CosNaming.NamingContextPackage.*;

// All CORBA applications need these classes.
import org.omg.CORBA.*;
import org.omg.PortableServer.*;
import org.omg.PortableServer.POA;

public class HelloServer 
{
  public static void main(String args[])
  {
    try{
    
      // Create and initialize the ORB
      ORB orb = ORB.init(args, null);
      
      // Activate the root POA
      POA rootpoa=POAHelper.narrow(orb.resolve_initial_references("RootPOA"));
      rootpoa.the_POAManager().activate();

      // Create and activate our own POA with a persistant
      // lifespan policy
  	  Policy[] policies = new Policy[2];
	  policies[0] = rootpoa.create_lifespan_policy(LifespanPolicyValue.PERSISTENT);
	  policies[1] = rootpoa.create_id_assignment_policy(IdAssignmentPolicyValue.USER_ID);
	  POA poa = rootpoa.create_POA("my_poa", null, policies);
      poa.the_POAManager().activate();
      	
      // Create the servant object
      HelloImpl helloRef = new HelloImpl();
      poa.activate_object_with_id("HELLO1234".getBytes(), helloRef);
	  org.omg.CORBA.Object ref= poa.servant_to_reference(helloRef);
      Hello href=HelloHelper.narrow(ref);
      
	  // Register Object reference with name service
      org.omg.CORBA.Object objRef = orb.resolve_initial_references("NameService");
      NamingContextExt ncRef = NamingContextExtHelper.narrow(objRef);
      ncRef.rebind(ncRef.to_name("HelloWorld"), href);
         
	  System.out.println("HelloServer is running...");
	  
	  orb.run();
      
    } catch(Exception e) {
        System.err.println("ERROR: " + e);
        e.printStackTrace(System.out);
      }  
  }
}

